--- title: "wallaroo.task" type: docs linkTitle: "wallaroo.task" ---
class Task(wallaroo.object.Object):

Base class for all backend GraphQL API objects.

This class serves as a framework for API objects to be constructed based on a partially-complete JSON response, and to fill in their remaining members dynamically if needed.

Task( client: wallaroo.client.Client, data: Dict[str, Any], standalone=False)

Base constructor.

Each object requires:

- a GraphQL client - in order to fill its missing members dynamically
- an initial data blob - typically from unserialized JSON, contains at
- least the data for required members (typically the object's primary key) and optionally other data members.

def kill(self):

Kill this Task.

@staticmethod
def list_tasks( client: wallaroo.client.Client, workspace_id: int, killed: bool = False):
@staticmethod
def get_task_by_id(client: wallaroo.client.Client, task_id: str):
def id(*args, **kwargs):
def name(*args, **kwargs):
def workspace_id(*args, **kwargs):
def input_data(*args, **kwargs):
def status(*args, **kwargs):
def task_type(*args, **kwargs):
def created_at(*args, **kwargs):
def updated_at(*args, **kwargs):
def last_runs( self, limit: Optional[int] = None, status: Optional[str] = None) -> wallaroo.task_run.TaskRunList:

Return the runs associated with this task.

###### Parameters

- limit int The number of runs to return
- status str Return only runs with the matching status. One of "success", "failure", "running", "all"

class TaskList(typing.List[wallaroo.task.Task]):

Wraps a list of pipelines for display in a display-aware environment like Jupyter.

##### Inherited Members

builtins.list
  list
  clear
  copy
  append
  insert
  extend
  pop
  remove
  index
  count
  reverse
  sort